@@ -63,6 +63,10 @@ class MitmProxy:
             **self._get_upstream_proxy_args(),
         )
 
+        if options.get('disable_capture', False):
+            self.scopes = ['$^']
+            mitmproxy_opts.update(ignore_hosts=['.*'])
+
         # Options that are prefixed mitm_ are passed through to mitmproxy
         mitmproxy_opts.update(**{k[5:]: v for k, v in options.items() if k.startswith('mitm_')})
 
@@ -114,6 +118,11 @@ class MitmProxy:
             if custom_auth:
                 args['upstream_custom_auth'] = custom_auth
 
+            no_proxy = proxy_config.get('no_proxy')
+
+            if no_proxy:
+                args['no_proxy'] = no_proxy
+
         return args
 
 
