@@ -61,16 +61,13 @@ class RequestStorage:
         Args:
             request: The request to save.
         """
-        request_id = self._index_request(request)
-        request.id = request_id
+        request_id = str(uuid.uuid4())
         request_dir = self._get_request_dir(request_id)
         os.mkdir(request_dir)
+        request.id = request_id
 
         self._save(request, request_dir, 'request')
 
-    def _index_request(self, request):
-        request_id = str(uuid.uuid4())
-
         with self._lock:
             self._index.append(_IndexedRequest(
                 id=request_id,
@@ -78,8 +75,6 @@ class RequestStorage:
                 has_response=False)
             )
 
-        return request_id
-
     def _save(self, obj, dirname, filename):
         with open(os.path.join(dirname, filename), 'wb') as out:
             pickle.dump(obj, out)
@@ -180,6 +175,12 @@ class RequestStorage:
                         response.body, response.headers.get('Content-Encoding', 'identity')
                     )
                     request.response = response
+
+                    # The certificate data has been stored on the response but we make
+                    # it available on the request which is a more logical location.
+                    if hasattr(response, 'cert'):
+                        request.cert = response.cert
+                        del response.cert
             except (FileNotFoundError, EOFError):
                 pass
 
